@@ -163,7 +163,11 @@ impl Literal {
                         other_code => format!(r"L'\U{:08X}'", other_code),
                     })),
                     syn::Lit::Int(ref value) => {
-                        Ok(Literal::Expr(value.base10_digits().to_string()))
+                        if value.base10_parse::<i64>().is_err() {
+                            Ok(Literal::Expr(format!("{}ULL", value.base10_digits())))
+                        } else {
+                            Ok(Literal::Expr(value.base10_digits().to_string()))
+                        }
                     }
                     syn::Lit::Float(ref value) => {
                         Ok(Literal::Expr(value.base10_digits().to_string()))
@@ -489,13 +493,31 @@ impl Constant {
             _ => &self.value,
         };
 
-        if config.constant.allow_static_const && config.language == Language::Cxx {
-            out.write(if in_body { "inline " } else { "static " });
+        self.documentation.write(config, out);
+
+        let allow_constexpr = if let Type::Primitive(..) = self.ty {
+            config.constant.allow_constexpr
+        } else {
+            false
+        };
+
+        if (config.constant.allow_static_const || allow_constexpr)
+            && config.language == Language::Cxx
+        {
+            if allow_constexpr {
+                out.write("constexpr ")
+            }
+
+            if config.constant.allow_static_const {
+                out.write(if in_body { "inline " } else { "static " });
+            }
+
             if let Type::ConstPtr(..) = self.ty {
                 // Nothing.
             } else {
                 out.write("const ");
             }
+
             self.ty.write(config, out);
             write!(out, " {} = ", name);
             value.write(config, out);
