@@ -17,6 +17,7 @@ use crate::bindgen::library::Library;
 use crate::bindgen::mangle;
 use crate::bindgen::monomorph::Monomorphs;
 use crate::bindgen::rename::{IdentifierType, RenameRule};
+use crate::bindgen::reserved;
 use crate::bindgen::utilities::find_first_some;
 use crate::bindgen::writer::{ListType, Source, SourceWriter};
 
@@ -421,8 +422,11 @@ impl Item for Enum {
         }
 
         for variant in &mut self.variants {
-            if let Some((_, ref mut body)) = variant.body {
+            reserved::escape(&mut variant.export_name);
+
+            if let Some((ref mut field_name, ref mut body)) = variant.body {
                 body.rename_for_config(config);
+                reserved::escape(field_name);
             }
         }
 
@@ -921,6 +925,7 @@ impl Source for Enum {
                 out.new_line();
                 write!(out, "switch (tag)");
                 out.open_brace();
+                let mut exhaustive = true;
                 for variant in &self.variants {
                     if let Some((ref variant_name, _)) = variant.body {
                         let condition = variant.cfg.to_condition(config);
@@ -936,9 +941,13 @@ impl Source for Enum {
                         );
                         condition.write_after(config, out);
                         out.new_line();
+                    } else {
+                        exhaustive = false;
                     }
                 }
-                write!(out, "default: return true;");
+                if !exhaustive {
+                    write!(out, "default: return true;");
+                }
                 out.close_brace(false);
                 out.close_brace(false);
 
@@ -984,6 +993,7 @@ impl Source for Enum {
                 out.open_brace();
                 write!(out, "switch (tag)");
                 out.open_brace();
+                let mut exhaustive = true;
                 for variant in &self.variants {
                     if let Some((ref variant_name, ref item)) = variant.body {
                         let condition = variant.cfg.to_condition(config);
@@ -998,9 +1008,13 @@ impl Source for Enum {
                         );
                         condition.write_after(config, out);
                         out.new_line();
+                    } else {
+                        exhaustive = false;
                     }
                 }
-                write!(out, "default: break;");
+                if !exhaustive {
+                    write!(out, "default: break;");
+                }
                 out.close_brace(false);
                 out.close_brace(false);
             }
@@ -1022,6 +1036,7 @@ impl Source for Enum {
                 out.open_brace();
                 write!(out, "switch (tag)");
                 out.open_brace();
+                let mut exhaustive = true;
                 for variant in &self.variants {
                     if let Some((ref variant_name, ref item)) = variant.body {
                         let condition = variant.cfg.to_condition(config);
@@ -1038,9 +1053,13 @@ impl Source for Enum {
                         );
                         condition.write_after(config, out);
                         out.new_line();
+                    } else {
+                        exhaustive = false;
                     }
                 }
-                write!(out, "default: break;");
+                if !exhaustive {
+                    write!(out, "default: break;");
+                }
                 out.close_brace(false);
                 out.close_brace(false);
 
